pub trait Chain<I: Index>: Seal<I> {
type Element;
// Required methods
fn get(&self) -> &Self::Element;
fn get_mut(&mut self) -> &mut Self::Element;
}Expand description
A trait for accessing elements in a type-level list.
Type Parameters
I: The index of the element in the list, which must implement theIndextrait.
This trait is sealed and cannot be implemented outside of this crate.